/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctDrawBoard.h
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

#ifndef CT_DRAWBOARD_H
#define CT_DRAWBOARD_H

/*------------------------------------------------------------- Includes */

#include <qwidget.h>
#include <qstring.h>

#include "ctPosition.h"

/*--------------------------------------------------------- Const values */

/** Margin in x direction in pixel */
const int X_MARGIN = 30;
/** Margin in y direction in pixel */
const int Y_MARGIN = 30;
/** Y coordinate for the column letters */
const int COLUMNS_Y = 270;
/** X coordinate for the row letters */
const int ROWS_X = 270;

/*-------------------------------------------------------------- Classes */

/** Draws a chess board from a \a ctPosition
representing the pieces on the board. 
@see ctPosition
*/
class ctDrawBoard : public QWidget
{
    Q_OBJECT

public:
    ctDrawBoard( QWidget *parent, const char *name = 0 );

public slots:
    void slotSetPosition(const ctPosition &);
    void slotSetTaskNumber(const QString &);
    void slotSetBoardEnable(bool);
    void slotGetPosition();
    void slotSetPiece(unsigned int);
    void slotClearBoard();
    void slotInitialPosition();
    void slotCopyLaTeXPosition();
    void slotCopyHTMLPosition(const QString &graphicsDir);

signals:
    void sigSetPosition(const ctPosition &);

protected:

private:    
    /** Current position */
    ctPosition iPosition;
    /** Number of the current task */
    QString sTaskNumber;
    /** Current piece that is set by a left mouse click */
    unsigned int iPiece;
    /** Is ``true'' if the board display is enabled,
        ``false'' else */
    bool bEnabled;	

    void paintEvent(QPaintEvent *);
    void mousePressEvent(QMouseEvent *);

    void setupConnects();
    void drawCurrentBoard(QPainter *paint);
    void drawColumnLetter(QPainter *paint, unsigned int index);
    void drawRowLetter(QPainter *paint, unsigned int index);
    void drawTaskNumber(QPainter *paint);
    void drawPieceBitmap(QPainter *paint, 
                         unsigned int index, 
			 unsigned int row, 
			 unsigned int col);

};

#endif


