/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctSignalRouter.h
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

#ifndef CT_SIGNALROUTER_H
#define CT_SIGNALROUTER_H

/*------------------------------------------------------------- Includes */

#include <qobject.h>

/*-------------------------------------------------------------- Classes */

/** This class is directly derived from \a QObject and has a special
purpose. It distributes or ``routes'' signals between widgets that do
not have a direct connection, i.e. do not know of each other normally.
By means of providing an appropriate \a signal and \a slot both communication
partners can connect to, the widgets can exchange information via the
\a ctSignalRouter. Basically, this is not very much different from offering
a global variable, being a pointer to a data structure, to all modules for
direct access.

The single instance of this class is evoked in the constructor of
\a ctMainWindow.
@see ctMainWindow
@warning Be sure to evoke just ONE instance of \a ctMainWindow for the
         application! Otherwise the pointer to the current signal router
	 gets overwritten by the new one. Thus, memory leakage occurs.
*/
class ctSignalRouter: public QObject
{
    Q_OBJECT

public:
    ctSignalRouter();

public slots:
    void slotOpenFile();
    void slotAddFile();
    void slotSaveFile();
    void slotExportLaTeXFile();
    void slotExportChessCardsFile();
    void slotExportHTML();
    void slotExportLaTeXDirectory();
    void slotExportChessCardsDirectory();
    void slotExportHTMLDirectory();
    void slotCopyLaTeXPosition();
    void slotCopyHTMLPosition();
    void slotImportFENFile();
    void slotImportEPDFile();
    void slotDeleteAll();

    void slotInsertTask();
    void slotCopyTask();
    void slotFirstTask();
    void slotTaskBack();
    void slotTaskForward();
    void slotLastTask();
    void slotDeleteTask();
    void slotClearBoard();
    void slotInitialPosition();
    void slotSetMainTitle();
    void slotRestoreTask();
    void slotGenerateTitles();

    void slotSetA4PaperSizeEnable(bool);
    void slotSetLaTeXDiagramSize(int);
    void slotSetTwoColumnsEnable(bool);
    void slotSetOneFileEnable(bool);
    void slotSetUseTTFontEnable(bool);
    void slotSetExpandSymbolsEnable(bool);
    void slotSetOutputSolutionsEnable(bool);
    void slotSetDirLevel(int);
    void slotSetFontSize(int);

signals:
    void sigOpenFile();
    void sigAddFile();
    void sigSaveFile();
    void sigExportLaTeXFile();
    void sigExportChessCardsFile();
    void sigExportHTML();
    void sigExportLaTeXDirectory();
    void sigExportChessCardsDirectory();
    void sigExportHTMLDirectory();
    void sigCopyLaTeXPosition();
    void sigCopyHTMLPosition();
    void sigImportFENFile();
    void sigImportEPDFile();
    void sigDeleteAll();

    void sigInsertTask();
    void sigCopyTask();
    void sigFirstTask();
    void sigTaskBack();
    void sigTaskForward();
    void sigLastTask();
    void sigDeleteTask();
    void sigClearBoard();
    void sigInitialPosition();
    void sigSetMainTitle();
    void sigRestoreTask();
    void sigGenerateTitles();

    void sigSetA4PaperSizeEnable(bool);
    void sigSetLaTeXDiagramSize(int);
    void sigSetTwoColumnsEnable(bool);
    void sigSetOneFileEnable(bool);
    void sigSetUseTTFontEnable(bool);
    void sigSetExpandSymbolsEnable(bool);
    void sigSetOutputSolutionsEnable(bool);
    void sigSetDirLevel(int);
    void sigSetFontSize(int);

protected:

private:

};

/*----------------------------------------------------- Global variables */

/** The signal router for the application */
extern ctSignalRouter *srChessTask;

#endif

